@@ -33,10 +33,10 @@ static boost::python::object sequence_get_item_slice(const Container& self, cons
     Py_ssize_t stop = -1;
 
     if (slice.start().ptr() != Py_None)
-        start = PyInt_AS_LONG(slice.start().ptr());
+        start = boost::python::extract<Py_ssize_t>(slice.start());
 
     if (slice.stop().ptr() != Py_None)
-        stop = PyInt_AS_LONG(slice.stop().ptr());
+        stop = boost::python::extract<Py_ssize_t>(slice.stop());
 
     return boost::python::object(self.mid(start, stop));
 }
